@@ -12,5 +12,5 @@
 #define NMIDI 1
 int NumMidi = NMIDI;
 struct midi_config midi_conf[NMIDI] =
-    {{0x300, 5}};
+    {{0x330, 9}};			/* 'standard' MPU401 */
 struct midi_softc midi_sc[NMIDI];
